@@ -1006,6 +1006,17 @@ class NumerousAdminClient(NumerousClient):
     def get_execution_status(self, exe_id):
         return self._job_manager.GetExecutionStatus(spm_pb2.ExecutionId(execution_id=exe_id)).json
 
+    def update_job_by_backend(self, project, scenario, job, exe, message, status, log, complete):
+        self._base_client.SetScenarioProgress(spm_pb2.ScenarioProgress(
+            project=project, scenario=scenario, spm_job_id=job,
+            message=message, status=status, clean=True, progress=0
+        ))
+        if complete:
+            self._base_client.CompleteExecution(
+                spm_pb2.ExecutionMessage(project_id=project, scenario_id=scenario, job_id=job,
+                                         execution_id=exe))
+
+        return spm_pb2.Empty()
 
 @contextmanager
 def open_admin_client() -> NumerousAdminClient:
